# coding: utf-8

# flake8: noqa

"""
    Mentortools Landing Page API

    Mentortools service for building and publishing landing pages

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.2.1+2699083666"

# import apis into sdk package
from landing_page_server_connector.api.default_api import DefaultApi

# import ApiClient
from landing_page_server_connector.api_response import ApiResponse
from landing_page_server_connector.api_client import ApiClient
from landing_page_server_connector.configuration import Configuration
from landing_page_server_connector.exceptions import OpenApiException
from landing_page_server_connector.exceptions import ApiTypeError
from landing_page_server_connector.exceptions import ApiValueError
from landing_page_server_connector.exceptions import ApiKeyError
from landing_page_server_connector.exceptions import ApiAttributeError
from landing_page_server_connector.exceptions import ApiException

# import models into sdk package
from landing_page_server_connector.models.address import Address
from landing_page_server_connector.models.editor_version_enum import EditorVersionEnum
from landing_page_server_connector.models.form_get import FormGet
from landing_page_server_connector.models.form_group_patch import FormGroupPatch
from landing_page_server_connector.models.form_list_get import FormListGet
from landing_page_server_connector.models.form_new import FormNew
from landing_page_server_connector.models.form_patch import FormPatch
from landing_page_server_connector.models.form_submit_request import FormSubmitRequest
from landing_page_server_connector.models.form_submit_response import FormSubmitResponse
from landing_page_server_connector.models.form_submit_response_type_enum import FormSubmitResponseTypeEnum
from landing_page_server_connector.models.form_update import FormUpdate
from landing_page_server_connector.models.form_validate_request import FormValidateRequest
from landing_page_server_connector.models.funnel_get import FunnelGet
from landing_page_server_connector.models.funnel_group_patch import FunnelGroupPatch
from landing_page_server_connector.models.funnel_landings_assign import FunnelLandingsAssign
from landing_page_server_connector.models.funnel_list_get import FunnelListGet
from landing_page_server_connector.models.funnel_new import FunnelNew
from landing_page_server_connector.models.funnel_patch import FunnelPatch
from landing_page_server_connector.models.http_validation_error import HTTPValidationError
from landing_page_server_connector.models.id_wrapper import IdWrapper
from landing_page_server_connector.models.import_tss_template import ImportTssTemplate
from landing_page_server_connector.models.input_field import InputField
from landing_page_server_connector.models.landing_get import LandingGet
from landing_page_server_connector.models.landing_group_patch import LandingGroupPatch
from landing_page_server_connector.models.landing_history_get import LandingHistoryGet
from landing_page_server_connector.models.landing_history_list_get import LandingHistoryListGet
from landing_page_server_connector.models.landing_import_override import LandingImportOverride
from landing_page_server_connector.models.landing_list_get import LandingListGet
from landing_page_server_connector.models.landing_new import LandingNew
from landing_page_server_connector.models.landing_patch import LandingPatch
from landing_page_server_connector.models.landing_script import LandingScript
from landing_page_server_connector.models.landing_script_get import LandingScriptGet
from landing_page_server_connector.models.landing_update import LandingUpdate
from landing_page_server_connector.models.list_sort_by_enum import ListSortByEnum
from landing_page_server_connector.models.optin_method import OptinMethod
from landing_page_server_connector.models.parsed_form import ParsedForm
from landing_page_server_connector.models.parsed_script import ParsedScript
from landing_page_server_connector.models.portal_homepage_set import PortalHomepageSet
from landing_page_server_connector.models.portal_language_enum import PortalLanguageEnum
from landing_page_server_connector.models.response_wrapper import ResponseWrapper
from landing_page_server_connector.models.response_wrapper_bool import ResponseWrapperBool
from landing_page_server_connector.models.response_wrapper_form_get import ResponseWrapperFormGet
from landing_page_server_connector.models.response_wrapper_form_submit_response import ResponseWrapperFormSubmitResponse
from landing_page_server_connector.models.response_wrapper_funnel_get import ResponseWrapperFunnelGet
from landing_page_server_connector.models.response_wrapper_id_wrapper import ResponseWrapperIdWrapper
from landing_page_server_connector.models.response_wrapper_int import ResponseWrapperInt
from landing_page_server_connector.models.response_wrapper_landing_get import ResponseWrapperLandingGet
from landing_page_server_connector.models.response_wrapper_landing_history_get import ResponseWrapperLandingHistoryGet
from landing_page_server_connector.models.response_wrapper_list_form_list_get import ResponseWrapperListFormListGet
from landing_page_server_connector.models.response_wrapper_list_funnel_list_get import ResponseWrapperListFunnelListGet
from landing_page_server_connector.models.response_wrapper_list_landing_history_list_get import ResponseWrapperListLandingHistoryListGet
from landing_page_server_connector.models.response_wrapper_list_landing_list_get import ResponseWrapperListLandingListGet
from landing_page_server_connector.models.response_wrapper_list_str import ResponseWrapperListStr
from landing_page_server_connector.models.response_wrapper_list_template_list_get import ResponseWrapperListTemplateListGet
from landing_page_server_connector.models.response_wrapper_list_template_list_get_public import ResponseWrapperListTemplateListGetPublic
from landing_page_server_connector.models.response_wrapper_parsed_form import ResponseWrapperParsedForm
from landing_page_server_connector.models.response_wrapper_parsed_script import ResponseWrapperParsedScript
from landing_page_server_connector.models.response_wrapper_template_get import ResponseWrapperTemplateGet
from landing_page_server_connector.models.response_wrapper_template_get_public import ResponseWrapperTemplateGetPublic
from landing_page_server_connector.models.response_wrapper_union_landing_get_none_type import ResponseWrapperUnionLandingGetNoneType
from landing_page_server_connector.models.result import Result
from landing_page_server_connector.models.script_category import ScriptCategory
from landing_page_server_connector.models.script_element import ScriptElement
from landing_page_server_connector.models.script_parse_request import ScriptParseRequest
from landing_page_server_connector.models.script_placement import ScriptPlacement
from landing_page_server_connector.models.sort_direction_enum import SortDirectionEnum
from landing_page_server_connector.models.template_get import TemplateGet
from landing_page_server_connector.models.template_get_public import TemplateGetPublic
from landing_page_server_connector.models.template_group_patch import TemplateGroupPatch
from landing_page_server_connector.models.template_list_get import TemplateListGet
from landing_page_server_connector.models.template_list_get_public import TemplateListGetPublic
from landing_page_server_connector.models.template_new import TemplateNew
from landing_page_server_connector.models.template_patch import TemplatePatch
from landing_page_server_connector.models.template_update import TemplateUpdate
from landing_page_server_connector.models.validation_error import ValidationError
from landing_page_server_connector.models.validation_error_loc_inner import ValidationErrorLocInner



# coding: utf-8

"""
    Mentortools Landing Page API

    Mentortools service for building and publishing landing pages

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from landing_page_server_connector.models.response_wrapper_landing_get import ResponseWrapperLandingGet  # noqa: E501

class TestResponseWrapperLandingGet(unittest.TestCase):
    """ResponseWrapperLandingGet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseWrapperLandingGet:
        """Test ResponseWrapperLandingGet
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseWrapperLandingGet`
        """
        model = ResponseWrapperLandingGet()  # noqa: E501
        if include_optional:
            return ResponseWrapperLandingGet(
                done = True,
                result = landing_page_server_connector.models.landing_get.LandingGet(
                    html = '', 
                    css = '', 
                    js = '', 
                    components = landing_page_server_connector.models.components.Components(), 
                    styles = [
                        None
                        ], 
                    assets = [
                        None
                        ], 
                    theme = landing_page_server_connector.models.theme.Theme(), 
                    name = '', 
                    title = '', 
                    path = '', 
                    order = 56, 
                    editor_version = null, 
                    portal_id = 56, 
                    id = 56, 
                    funnel_id = 56, 
                    uuid = '', 
                    preview_id = '', 
                    google_analytics_pixel = '', 
                    google_tag_manager_pixel = '', 
                    facebook_pixel = '', 
                    tiktok_pixel = '', 
                    pinterest_pixel = '', 
                    custom_scripts = [
                        landing_page_server_connector.models.landing_script_get.LandingScriptGet(
                            elements = [
                                landing_page_server_connector.models.script_element.ScriptElement(
                                    tag = '', 
                                    content = '', 
                                    src = '', 
                                    href = '', 
                                    rel = '', )
                                ], 
                            title = '', 
                            category = 'analytics', 
                            placement = 'body', 
                            elements_str = '', )
                        ], 
                    requires_correction = True, 
                    is_homepage = True, 
                    noindex = True, 
                    created_at = 56, 
                    updated_at = 56, 
                    published_at = 56, ),
                error = ''
            )
        else:
            return ResponseWrapperLandingGet(
                done = True,
        )
        """

    def testResponseWrapperLandingGet(self):
        """Test ResponseWrapperLandingGet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Landing Page API

    Mentortools service for building and publishing landing pages

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from landing_page_server_connector.models.landing_list_get import LandingListGet  # noqa: E501

class TestLandingListGet(unittest.TestCase):
    """LandingListGet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LandingListGet:
        """Test LandingListGet
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LandingListGet`
        """
        model = LandingListGet()  # noqa: E501
        if include_optional:
            return LandingListGet(
                id = 56,
                portal_id = 56,
                funnel_id = 56,
                order = 56,
                uuid = '',
                editor_version = 1,
                name = '',
                title = '',
                path = '',
                preview_id = '',
                requires_correction = True,
                is_homepage = True,
                noindex = True,
                created_at = 56,
                updated_at = 56,
                published_at = 56
            )
        else:
            return LandingListGet(
                id = 56,
                portal_id = 56,
                order = 56,
                uuid = '',
                editor_version = 1,
                name = '',
                title = '',
                path = '',
                requires_correction = True,
                is_homepage = True,
                noindex = True,
                created_at = 56,
        )
        """

    def testLandingListGet(self):
        """Test LandingListGet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Landing Page API

    Mentortools service for building and publishing landing pages

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictBool, StrictStr

class InputField(BaseModel):
    """
    InputField
    """
    name: Optional[StrictStr] = None
    required: Optional[StrictBool] = False
    placeholder: Optional[StrictStr] = ''
    type: Optional[StrictStr] = ''
    value: Optional[StrictStr] = ''
    checked: Optional[StrictBool] = False
    __properties = ["name", "required", "placeholder", "type", "value", "checked"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> InputField:
        """Create an instance of InputField from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> InputField:
        """Create an instance of InputField from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return InputField.parse_obj(obj)

        _obj = InputField.parse_obj({
            "name": obj.get("name"),
            "required": obj.get("required") if obj.get("required") is not None else False,
            "placeholder": obj.get("placeholder") if obj.get("placeholder") is not None else '',
            "type": obj.get("type") if obj.get("type") is not None else '',
            "value": obj.get("value") if obj.get("value") is not None else '',
            "checked": obj.get("checked") if obj.get("checked") is not None else False
        })
        return _obj


